enableKeyboardNavigation property
Enable arrow-key navigation, Enter to select and Escape to close.
Defaults to false.
Implementation
final bool enableKeyboardNavigation;
Enable arrow-key navigation, Enter to select and Escape to close.
Defaults to false.
final bool enableKeyboardNavigation;