highlightMatchedText property
Highlight the matched substring within search results.
Only applicable to the search constructors and the default list item. Defaults to false.
Implementation
final bool highlightMatchedText;
Highlight the matched substring within search results.
Only applicable to the search constructors and the default list item. Defaults to false.
final bool highlightMatchedText;