recentSelectionsMaxCount property
Maximum number of recently-selected items pinned at the top of the list.
Defaults to 0, which disables the recently-selected section.
Implementation
final int recentSelectionsMaxCount;
Maximum number of recently-selected items pinned at the top of the list.
Defaults to 0, which disables the recently-selected section.
final int recentSelectionsMaxCount;