searchMatchTextStyle property

TextStyle? searchMatchTextStyle
final

Text style applied to the matched substring within search results.

Only applicable when highlightMatchedText is true and the default list item builder is used. Default to a bold span.

Implementation

final TextStyle? searchMatchTextStyle;