MultiSelectController<T> class

Controls an immutable, duplicate-free list of selected items.

Inheritance

Constructors

MultiSelectController(List<T> value)
Stores an immutable, duplicate-free snapshot of the selection.

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
hasValues → bool
Whether at least one item is selected.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ List<T>
The current value stored in this notifier.
getter/setter pairinherited-getteroverride-setter

Methods

add(T valueToAdd) → void
Selects an item, leaving already-selected items unchanged.
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clear() → void
Clears the current selection.
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
remove(T valueToRemove) → void
Deselects the matching item, if present.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited